Corrected project name in header comments
[pulseview.git] / signal.h
index edab476deb7d31c22f0b16929c2221e82e05cb1a..27bd5562e9b2b687639fe8d4d61660771743a626 100644 (file)
--- a/signal.h
+++ b/signal.h
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -20,7 +20,6 @@
 
 #include <boost/shared_ptr.hpp>
 
-#include <QGLWidget>
 #include <QPainter>
 #include <QRect>
 #include <QString>
@@ -41,15 +40,15 @@ public:
        QString get_name() const;
 
        /**
* Paints the signal into a QGLWidget.
* @param widget the QGLWidget to paint into.
         * @param rect the rectangular area to draw the trace into.
         * @param scale the scale in seconds per pixel.
         * @param offset the time to show at the left hand edge of
         *   the view in seconds.
         **/
-       virtual void paint(QGLWidget &widget, const QRect &rect,
-               double scale, double offset) = 0;
+       virtual void paint(QPainter &p, const QRect &rect, double scale,
+               double offset) = 0;
 
        /**
         * Paints the signal label into a QGLWidget.
@@ -41,15 +40,15 @@ public:
 
        /**
-        * Paints the signal into a QGLWidget.
-        * @param widget the QGLWidget to paint into.
+        * Paints the signal with a QPainter
+        * @param p the QPainter to paint into.
         * @param rect the rectangular area to draw the trace into.
         * @param scale the scale in seconds per pixel.